#
# spec file for package findutils (Version 4.4.0)
#
# Copyright (c) 2008 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           findutils
Url:            http://www.gnu.org/software/findutils/
License:        GNU Free Documentation License, Version 1.2 (GFDL 1.2); GPL v3 or later
Group:          Productivity/File utilities
Provides:       find 
Obsoletes:      find 
AutoReqProv:    on
PreReq:         %{install_info_prereq}
Version:        4.4.0
Release:        35
Summary:        GNU find--Finding Files
Source:         findutils-%{version}.tar.bz2
Source1:        sysconfig.locate
Source2:        cron.daily.updatedb
Patch:          findutils-%{version}.diff
Patch1:         findutils-%{version}-selinux.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libselinux-devel

%description
This package contains GNU find and xargs.  The programs comply with
POSIX 1003.2.  They also support additional options, some borrowed from
Unix and some unique to GNU.



Authors:
--------
    David J. MacKenzie <djm@gnu.org>
    Jan Brittenson <bson@gnu.org>
    Brian L. Matthews <blm@6sceng.UUCP>
    Mike Rendell <michael@cs.mun.ca>
    James A. Woods <jwoods@adobe.com>
    Jay Plett <jay@silence.princeton.nj.us>
    Tim Wood <tim@toad.com>

%package locate
License:        GPL v3 or later
Summary:        Tool for Locating Files (GNU Findutils Subpackage)
Group:          Productivity/File utilities
Provides:       findutils:/usr/bin/locate
AutoReqProv:    on
PreReq:         %fillup_prereq

%description locate
This package contains the locate program which is part of the GNU
findutils software suite.

You can find files fast using locate.  On installing findutils-locate
an additional daily cron job will be added to the cron system.	This
job will update the files database every night or shortly after
switching on the computer.



Authors:
--------
    David J. MacKenzie <djm@gnu.org>
    Jan Brittenson <bson@gnu.org>
    Brian L. Matthews <blm@6sceng.UUCP>
    Mike Rendell <michael@cs.mun.ca>
    James A. Woods <jwoods@adobe.com>
    Jay Plett <jay@silence.princeton.nj.us>
    Tim Wood <tim@toad.com>

%prep
%setup -q
%patch
%patch1 -p1

%build
./configure CFLAGS="$RPM_OPT_FLAGS" \
	    --prefix=%{_prefix} --libexecdir=%{_libdir}/find \
	    --localstatedir=/var/lib \
	    --infodir=%{_infodir} --mandir=%{_mandir} \
	    --without-included-regex \
  	    --without-fts \
	    --enable-d_type-optimisation
make

%install
make install DESTDIR=$RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/var/adm/fillup-templates
mkdir -p $RPM_BUILD_ROOT/etc/cron.daily
install -m 644 %{SOURCE1} $RPM_BUILD_ROOT/var/adm/fillup-templates
install -m 755 %{SOURCE2} $RPM_BUILD_ROOT/etc/cron.daily/suse.de-updatedb
%find_lang %name
rm -f $RPM_BUILD_ROOT%{_bindir}/oldfind
rm -f $RPM_BUILD_ROOT%{_bindir}/ftsfind
rm -f $RPM_BUILD_ROOT%{_infodir}/find-maint*

%clean
rm -rf $RPM_BUILD_ROOT

%post locate
%{fillup_only -n locate}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/find.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/find.info.gz

%files -f %name.lang
%defattr(-,root,root,755)
%doc README NEWS AUTHORS TODO
%{_bindir}/find
%{_bindir}/xargs
%doc %{_infodir}/find.info*.gz
%doc %{_mandir}/man1/find.1.gz
%doc %{_mandir}/man1/xargs.1.gz

%files locate
%defattr(-,root,root,755)
/etc/cron.daily/*
%{_bindir}/locate
%{_bindir}/updatedb
%{_libdir}/find
%doc %{_mandir}/man1/locate.1.gz
%doc %{_mandir}/man1/updatedb.1.gz
%doc %{_mandir}/man5/locatedb.5.gz
/var/adm/fillup-templates/*

%changelog
* Mon Aug 25 2008 prusnak@suse.cz
- enabled SELinux support [Fate#303662]
* Mon Aug 11 2008 schwab@suse.de
- Fix undefined behaviour.
* Mon Aug 04 2008 schwab@suse.de
- Don't use fts.
* Tue Mar 18 2008 schwab@suse.de
- Update to findutils 4.4.0.
  See NEWS for details.
* Sun Feb 24 2008 crrodriguez@suse.de
- use find_lang macro
* Thu Feb 14 2008 schwab@suse.de
- Update to findutils 4.2.33.
  ** Translations
  The following translations are new:
  Ukranian
  The following translations have been updated:
  Hungarian, Dutch, Slovenian, Swedish, Traditional Chinese,
  Polish, Irish, Portuguese, Slovak.
* Sat Jan 26 2008 schwab@suse.de
- Update to findutils 4.2.32.
  ** License changes
  This version of findutils is now distributed under version 3 (or
  later) of the GNU GPL.   The documentation is distributed under
  version 1.2 (or later) of the GNU Free Documentation License.
  ** Documentation Fixes
  [#19596]: -printf %%b should be compared with %%s/512, not %%s/1024.
  ** Bug Fixes
  [#21568]: When building from CVS in 4.2.x, we now check gnulib out using git
  instead of CVS.  This fixes Savannah bug 21568, the problem being that
  git-cvspserevr does not currently support -D, and the ond CVS server
  for gnulib has been frozen.
  [#20970]: Trailing slash on directory arguments breaks -name.  "find
  foo/ -name foo" now correctly matches foo and printf foo/.  See POSIX
  interp http://www.opengroup.org/austin/interps/uploads/40/14959/AI-186.txt
  [#20751]: Avoid memory corruption in find -ls that has been present
  since 4.2.28.
  [#20662]: Avoid memory leak in find -name and other places affected by
  gnulib dirname module.  The leak had been present since 4.2.28.
  [#20310]: configure uses hosts's support status for "sort -z" when
  generating the updatedb script for use on the target.  This is not a
  reliable strategy when cross-compiling, so assume no support for -z in
  that situation.
  [#20273]: When xargs is successful without consuming all of stdin (for
  example, with the -E option), and stdin is seekable, xargs now
  correctly restores the file position, even on platforms where exit()
  does not follow the POSIX rules of doing likewise.  Likewise for find
  (for example, with the -ok action).
  [#19660]: Fix compilation failure on Cygwin.
  [#15384]: Find misbehaves when parent directory is not readable.
  ** Enhancements
  [#20688]: The warning printed by -name or -iname when the pattern to
  match contains a slash can now be silenced by -nowarn.  This warning
  was originally introduced unconditionally in 4.2.21.
* Thu Jul 05 2007 schwab@suse.de
- Drop clean core script.
* Sun Jun 03 2007 schwab@suse.de
- Update to findutils 4.2.31.
  ** Security Fixes
  [#20014]: Findutils-4.2.31 includes a patch for a potential security
  problem in locate.  When locate read an old-format database, it read
  file names into a fixed-length buffer allocated on the heap without
  checking for overflow.  Although overflowing a heap buffer if often
  somewhat safer than overflowing a buffer on the stack, this bug still
  has potential security implications.
  All previous releases of findutils are affected by this bug.  It has
  been assigned CVE number CVE-2007-2452.
  ** Documentation Fixes
  [#19596]: Corrected the documentation for "find -printf %%b".
  [#19483]: updatedb manpage has inconsistent highlighting for --help
  option.
  [#19155]: Fixed typo in the output of "locate --help".
  ** Other Bug Fixes
  [#19658]: When cross-compiling, "make clean" no longer deletes the
  generated file doc/regexprops.texi, because there is no way to
  regenerate it.
  [#19484]: Decompressed data is wrong in locate if the first filename
  indexed by updatedb starts with a space (instead of a slash).
  ** Other Changes
  Findutils has switched to a new way of building the code from gnulib.
  There should be no functional difference; the change should not be
  visible to those using the findutils binaries, except for changes to
  the output of "find --version", which should now show the version of
  Gnulib which was used.
* Wed Feb 28 2007 schwab@suse.de
- Update to findutils 4.2.30.
  ** Bug Fixes
  Savannah Bug #13252: The test suite now works on platforms where
  DejaGnu is based on Tcl 8.3 (previously, 8.4 or later was required).
  Savannah Bug bug #17861: this version should build on Solaris and HPUX
  once again.
  Savannah Bug #18433: findutils now compiles if "--enable-debug" was
  specified as an option to configure.  Previously this caused a
  compilation failure in find.
  ** Documentation Fixes
  Some typos in the Texinfo manual and one typo in in the usage message
  for xargs have been fixed.
* Mon Feb 12 2007 schwab@suse.de
- Fix memleaks.
* Mon Dec 04 2006 schwab@suse.de
- Update to findutils 4.2.29.
  ** Documentation Fixes
  The global effect of options (other than -daystart and -follow) is now
  explained more clearly in the manual page.   Savannah bug #15360.
  ** Bug Fixes
  [#17782]: find -execdir now correctly puts the prefix "./" before the
  expansion of "{}" rather than at the start of the argument it appears
  in.  Please note that if you use the -exec or -execdir actions with a
  shell, then you may be vulnerable to shell code injection attacks, so
  don't do that.  It's not a security defect in find - you should not be
  passing untrusted data (such as file names chosen by other people) to
  the shell.
  [#17477]: find -printf '%%' (that is, where the format has a trailing %%)
  now generates an error message.
* Mon Nov 20 2006 schwab@suse.de
- cron.daily.clean_core: robustify even more.
* Mon Oct 16 2006 schwab@suse.de
- cron.daily.clean_core: robustify to avoid matching non-cores [#210987].
* Mon Aug 07 2006 schwab@suse.de
- Update to findutils 4.2.28.
  ** Bug Fixes
  Savannah bug #15800: If find finds more subdirectories within a parent
  directory than it previously expected to based on the link count of
  the parent, the resulting error message now gives the correct
  directory name (previously an error message was issued but it
  specified the wrong directory).
  Savannah bug #16738: "find .... -exec ... {} +" now works if you have
  a large environment and many files must be passed to the -exec
  action.  The same problem affected the -execdir action, though since
  the number of files in a given directory will normally be smaller, the
  problem was worse for -exec.
  Savannah bug #16579: Updatedb now works if it is running as a user
  whose login shell is not actually a shell.
  ** Translations
  The following translations have been updated:
  Vietnamese, Belarusian, Catalan, Danish, German, Greek, Esperanto,
  Spanish, Estonian, Finnish, French, Irish, Galician, Croatian, Hungarian,
  Indonesian, Italian, Japanese, Korean, Luganda, Malay, Dutch, Polish,
  Portuguese, Brazilian Portuguese, Romanian, Russian, Kinyarwanda,
  Slovak, Slovenian, Serbian, Swedish, Turkish, Chinese (simplified),
  Chinese (traditional), Bulgarian
* Mon Jul 24 2006 rguenther@suse.de
- Do not run autoreconf.
* Mon Jul 24 2006 schwab@suse.de
- Add 9P to PRUNEFS [#129339].
* Fri Jun 30 2006 schwab@suse.de
- Add nfs4 to PRUNEFS [#189281].
* Thu Mar 23 2006 schwab@suse.de
- Add /sys to UPDATEDB_PRUNEPATHS [#160354].
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 schwab@suse.de
- Fix permissions of cron scripts [#138550].
* Wed Dec 07 2005 schwab@suse.de
- Update to findutils 4.2.27.
* Mon Dec 05 2005 schwab@suse.de
- Drop SELinux support.
* Tue Nov 22 2005 schwab@suse.de
- Update to findutils 4.2.26.
* Wed Oct 19 2005 schwab@suse.de
- Add cifs to the default for PRUNEFS [#129339].
* Wed Oct 05 2005 schwab@suse.de
- Cleanup.
* Sun Sep 25 2005 schwab@suse.de
- Fix warnings.
* Sun Sep 04 2005 schwab@suse.de
- Update to findutils 4.2.25.
* Sun Sep 04 2005 schwab@suse.de
- Don't link libselinux statically.
* Mon Aug 01 2005 mmj@suse.de
- Make updatedb run as an idle io process
* Sun Jun 26 2005 schwab@suse.de
- Make regex syntax compatible to previous versions again.
* Mon Jun 20 2005 schwab@suse.de
- Update to findutils 4.2.23.
* Wed Jun 01 2005 schwab@suse.de
- Rename cron scripts.
* Thu Mar 24 2005 schwab@suse.de
- Update to findutils 4.2.20.
* Wed Mar 09 2005 schwab@suse.de
- Update to findutils 4.2.19 [#71803].
* Sat Feb 19 2005 schwab@suse.de
- Update to findutils 4.2.18.
* Mon Jan 31 2005 schwab@suse.de
- Update to findutils 4.2.15.
* Wed Jan 26 2005 schwab@suse.de
- Update to findutils 4.2.14.
* Mon Jan 24 2005 schwab@suse.de
- Update to findutils 4.2.13.
* Mon Jan 17 2005 schwab@suse.de
- Fix use of next_element.
* Wed Jan 12 2005 schwab@suse.de
- Update to findutils 4.2.11.
* Mon Nov 22 2004 schwab@suse.de
- Update to findutils 4.2.7.
* Tue Nov 02 2004 schwab@suse.de
- Update to findutils 4.2.3.
* Tue Oct 26 2004 schwab@suse.de
- Update to findutils 4.2.2.
* Thu Aug 05 2004 schwab@suse.de
- Update to findutils 4.1.20.
* Thu Jul 29 2004 schwab@suse.de
- Add patch to support d_type.
- Add patch to support POSIX xargs options.
* Mon Mar 15 2004 kukuk@suse.de
- Adjust for new SELinux version
* Sat Dec 13 2003 schwab@suse.de
- Fix file list.
* Tue Nov 11 2003 schwab@suse.de
- Terminate xargs help output with a newline.
* Wed Oct 15 2003 schwab@suse.de
- Cleanup selinux patch.
* Wed Oct 15 2003 ro@suse.de
- link libselinux static
* Wed Oct 15 2003 kukuk@suse.de
- Add selinux patch
- Build not as root
- Fix permissions in RPM filelist
* Fri Oct 03 2003 kukuk@suse.de
- Remove tetex from neededforbuild
* Tue May 13 2003 schwab@suse.de
- Add %%defattr.
- Fix file list.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr 07 2003 schwab@suse.de
- Only delete info entries when removing last version.
* Thu Mar 06 2003 schwab@suse.de
- Fix clean_core cron script [#22758]:
  * use /etc/sysconfig/locate
  * add proper quoting
  * use mtime for finding old cores.
- Fix feedback address.
* Thu Feb 06 2003 schwab@suse.de
- Use %%install_info.
* Tue Dec 10 2002 schwab@suse.de
- Add meta tags to fillup templates.
* Fri Aug 09 2002 bk@suse.de
- findutils-locate: use nice -n 19 for the daily cronjob of updatedb
* Mon Aug 05 2002 schwab@suse.de
- Fix missing newline [#17427].
* Wed Jul 31 2002 schwab@suse.de
- Add PreReq for locate.
* Sun Jun 23 2002 schwab@suse.de
- Make -name conforming to POSIX.
* Fri Mar 08 2002 schwab@suse.de
- Add some documentation [#14733].
* Mon Feb 25 2002 schwab@suse.de
- Fix permissions.
* Wed Feb 06 2002 ro@suse.de
- sysconfig/cron_daily -> sysconfig/cron
* Thu Jan 31 2002 ro@suse.de
- added sysconfig.locate and cron.daily scripts updatedb and
  clean core to locate subpackage
* Thu Jan 31 2002 schwab@suse.de
- Put locate and related programs in their own subpackage.
* Thu Jun 07 2001 schwab@suse.de
- Update to findutils 4.1.7.
* Thu Nov 23 2000 bk@suse.de
- added suse update config macro, was needed for s390
* Tue Oct 24 2000 schwab@suse.de
- Update to findutils 4.1.6.
- Renamed from find.
* Fri Oct 13 2000 schwab@suse.de
- Fix substitution in updatedb script.
* Wed Sep 13 2000 schwab@suse.de
- Fix compilation problem with getline.
- Don't use included regex.
* Wed Sep 13 2000 schwab@suse.de
- Update to findutils 4.1.3.
* Thu Mar 16 2000 schwab@suse.de
- xargs: Move arg_max limit check after environ size check.
* Wed Feb 02 2000 schwab@suse.de
- Fix substitutions in updatedb.
* Mon Jan 17 2000 schwab@suse.de
- /usr/{info,man} -> /usr/share/{info,man}
- Get rid of Makefile.Linux
- Remove some obsolete changes
* Mon Nov 15 1999 kukuk@suse.de
- fix returncode from dostat and dolstat
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Aug 26 1999 schwab@suse.de
- fix "find -false , -name ."
* Fri Dec 18 1998 ro@suse.de
- for glibc: use getline from libc
* Tue Sep 01 1998 ro@suse.de
- fixed macro problems with strcpy,strdup,...
* Thu May 14 1998 florian@suse.de
- added "-s /bin/sh" to further 2 places
- also prune "afs smbfs autofs" filesystems
- fix "find / -xtype l"
- xargs: raise default limit of 20k to 80k for the environment and
  all command parameters
* Mon Nov 10 1997 bs@suse.de
- added "-s /bin/sh" to su command in updatedb (our nobody has /bin/false
  for default shell)
* Mon Apr 14 1997 florian@suse.de
- add bug-fixes from debian and gnu.utils.bugs
- updatedb now supports "--prunefs"
- "mv /usr/libexec/* /usr/lib/find/"
